@@ -108,9 +108,12 @@ def resolve_topic_partition(discovery_result: dict, partition: TopicPartition) -
     return TopicPartition(resolve_topic(discovery_result, partition.topic), partition.partition, partition.offset)
 
 
-def resolve_topic_partitions(discovery_result: dict, partitions: List[TopicPartition]) -> Optional[List[TopicPartition]]:
-    if not partitions:
+def resolve_topic_partitions(discovery_result: dict,
+                             partitions: List[TopicPartition]) -> Optional[List[TopicPartition]]:
+    if partitions is None:
         return None
+    if len(partitions) == 0:
+        return []
     return [resolve_topic_partition(discovery_result, topic_partition) for topic_partition in partitions]
 
 
@@ -120,8 +123,8 @@ def unresolve_topic_partition(discovery_result: dict, partition: TopicPartition)
     return TopicPartition(unresolve_topic(discovery_result, partition.topic), partition.partition, partition.offset)
 
 
-def unresolve_topic_partitions \
-                (discovery_result: dict, partitions: List[TopicPartition]) -> Optional[List[TopicPartition]]:
+def unresolve_topic_partitions(discovery_result: dict,
+                               partitions: List[TopicPartition]) -> Optional[List[TopicPartition]]:
     if not partitions:
         return None
     return [unresolve_topic_partition(discovery_result, topic_partition) for topic_partition in partitions]
